==> haskell-byteable-0.1.1-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byteable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 byteable
version:              0.1.1
visibility:           public
id:                   byteable-0.1.1-2aVcTelA6XA9YKIvhjRaxC
key:                  byteable-0.1.1-2aVcTelA6XA9YKIvhjRaxC
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-byteable
synopsis:             Type class for sequence of bytes
description:
    Abstract class to manipulate sequence of bytes

    The use case of this class is abstracting manipulation of
    types that are just wrapping a bytestring with stronger and
    more meaniful name.

    Usual definition of those types are of the form: newtype MyType = MyType ByteString

category:             Data
abi:                  aaa2249326b802c6c2e11a611096c6e2
exposed:              True
exposed-modules:      Data.Byteable
import-dirs:          /usr/lib/ghc-9.2.8/site-local/byteable-0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/byteable-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byteable
hs-libraries:         HSbyteable-0.1.1-2aVcTelA6XA9YKIvhjRaxC
depends:              base-4.16.4.0 bytestring-0.11.4.0
haddock-interfaces:   /usr/share/doc/haskell-byteable/html/byteable.haddock
haddock-html:         /usr/share/doc/haskell-byteable/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-byteable-0.1.1-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byteable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 byteable
version:              0.1.1
visibility:           public
id:                   byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY
key:                  byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-byteable
synopsis:             Type class for sequence of bytes
description:
    Abstract class to manipulate sequence of bytes

    The use case of this class is abstracting manipulation of
    types that are just wrapping a bytestring with stronger and
    more meaniful name.

    Usual definition of those types are of the form: newtype MyType = MyType ByteString

category:             Data
abi:                  c689745ee38c4f0571d06b974164fa6c
exposed:              True
exposed-modules:      Data.Byteable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/byteable-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/byteable-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/byteable-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byteable
hs-libraries:         HSbyteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-byteable/html/byteable.haddock
haddock-html:         /usr/share/doc/haskell-byteable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
